@@ -1,4 +1,4 @@
-#define PJ_LIB_
+
 
 #include <math.h>
 
@@ -23,7 +23,7 @@ static PJ_XY wag7_s_forward(PJ_LP lp, PJ *P) { /* Spheroidal, forward */
     return (xy);
 }
 
-PJ *PROJECTION(wag7) {
+PJ *PJ_PROJECTION(wag7) {
     P->fwd = wag7_s_forward;
     P->inv = nullptr;
     P->es = 0.;
