@@ -76,8 +76,6 @@ Engsager
  *
  *****************************************************************************/
 
-#define PJ_LIB_
-
 #include <cassert>
 #include <complex>
 #include <cstdint>
@@ -551,7 +549,7 @@ static int parse_coefs(PJ *P, double *coefs, const char *param, int ncoefs) {
 }
 
 /*********************************************************************/
-PJ *PROJECTION(horner) {
+PJ *PJ_PROJECTION(horner) {
     /*********************************************************************/
     int degree = 0;
     HORNER *Q;
